import type { CompileError, CompileResult } from 'svelte/compiler';
import { EditorState } from '@codemirror/state';
import { EditorView } from 'codemirror';
import type { Diagnostic } from '@codemirror/lint';
export interface File {
    type: 'file';
    name: string;
    basename: string;
    contents: string;
    text: boolean;
}
export interface Directory {
    type: 'directory';
    name: string;
    basename: string;
}
export type Item = File | Directory;
export interface Compiled {
    error: CompileError | null;
    result: CompileResult | null;
    migration: {
        code: string;
    } | null;
}
export interface ExposedCompilerOptions {
    generate: 'client' | 'server';
    dev: boolean;
    modernAst: boolean;
}
export declare class Workspace {
    #private;
    creating: {
        parent: string;
        type: "file" | "directory";
    } | null;
    modified: Record<string, boolean>;
    compiled: Record<string, Compiled>;
    states: Map<string, EditorState>;
    diagnostics: Diagnostic[];
    constructor(files: Item[], { svelte_version, initial, readonly, onupdate, onreset }?: {
        svelte_version?: string;
        initial?: string;
        readonly?: boolean;
        onupdate?: (file: File) => void;
        onreset?: (items: Item[]) => void;
    });
    get files(): Item[];
    get compiler_options(): ExposedCompilerOptions;
    get current(): File;
    get current_compiled(): Compiled | null;
    add(item: Item): Item;
    disable_tab_indent(): void;
    enable_tab_indent(): void;
    focus(): void;
    highlight_range(node: {
        start: number;
        end: number;
    } | null, scroll?: boolean): void;
    mark_saved(): void;
    link(view: EditorView): Promise<void>;
    move(from: Item, to: Item): void;
    onhover(fn: (pos: number | null) => void): void;
    onselect(fn: (from: number, to: number) => void): void;
    remove(item: Item): void;
    rename(previous: Item, name: string): void;
    reset(new_files: Item[], selected?: string): void;
    select(name: string): void;
    set(files: Item[], selected?: string): void;
    unlink(view: EditorView): void;
    update_compiler_options(options: Partial<ExposedCompilerOptions>): void;
    update_file(file: File): void;
    get vim(): boolean;
    set vim(value: boolean);
}
